# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.peggy.v1 import attestation_pb2 as injective_dot_peggy_dot_v1_dot_attestation__pb2
from injective.peggy.v1 import types_pb2 as injective_dot_peggy_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1finjective/peggy/v1/events.proto\x12\x12injective.peggy.v1\x1a\x14gogoproto/gogo.proto\x1a$injective/peggy/v1/attestation.proto\x1a\x1einjective/peggy/v1/types.proto\"\xac\x01\n\x18\x45ventAttestationObserved\x12\x37\n\x10\x61ttestation_type\x18\x01 \x01(\x0e\x32\x1d.injective.peggy.v1.ClaimType\x12\x17\n\x0f\x62ridge_contract\x18\x02 \x01(\t\x12\x17\n\x0f\x62ridge_chain_id\x18\x03 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x04 \x01(\x0c\x12\r\n\x05nonce\x18\x05 \x01(\x04\"O\n\x1b\x45ventBridgeWithdrawCanceled\x12\x17\n\x0f\x62ridge_contract\x18\x01 \x01(\t\x12\x17\n\x0f\x62ridge_chain_id\x18\x02 \x01(\x04\"\x83\x01\n\x12\x45ventOutgoingBatch\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\x12\x13\n\x0b\x62\x61tch_nonce\x18\x03 \x01(\x04\x12\x15\n\rbatch_timeout\x18\x04 \x01(\x04\x12\x14\n\x0c\x62\x61tch_tx_ids\x18\x05 \x03(\x04\"o\n\x1a\x45ventOutgoingBatchCanceled\x12\x17\n\x0f\x62ridge_contract\x18\x01 \x01(\t\x12\x17\n\x0f\x62ridge_chain_id\x18\x02 \x01(\x04\x12\x10\n\x08\x62\x61tch_id\x18\x03 \x01(\x04\x12\r\n\x05nonce\x18\x04 \x01(\x04\"\xe1\x01\n\x18\x45ventValsetUpdateRequest\x12\x14\n\x0cvalset_nonce\x18\x01 \x01(\x04\x12\x15\n\rvalset_height\x18\x02 \x01(\x04\x12;\n\x0evalset_members\x18\x03 \x03(\x0b\x32#.injective.peggy.v1.BridgeValidator\x12\x45\n\rreward_amount\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x14\n\x0creward_token\x18\x05 \x01(\t\"v\n\x1d\x45ventSetOrchestratorAddresses\x12\x19\n\x11validator_address\x18\x01 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\x12\x1c\n\x14operator_eth_address\x18\x03 \x01(\t\"H\n\x12\x45ventValsetConfirm\x12\x14\n\x0cvalset_nonce\x18\x01 \x01(\x04\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\"\xd0\x01\n\x0e\x45ventSendToEth\x12\x16\n\x0eoutgoing_tx_id\x18\x01 \x01(\x04\x12\x0e\n\x06sender\x18\x02 \x01(\t\x12\x10\n\x08receiver\x18\x03 \x01(\t\x12?\n\x06\x61mount\x18\x04 \x01(\tB/\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\xc8\xde\x1f\x00\x12\x43\n\nbridge_fee\x18\x05 \x01(\tB/\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\xc8\xde\x1f\x00\"F\n\x11\x45ventConfirmBatch\x12\x13\n\x0b\x62\x61tch_nonce\x18\x01 \x01(\x04\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\"R\n\x14\x45ventAttestationVote\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x02 \x01(\x0c\x12\r\n\x05voter\x18\x03 \x01(\t\"\x8c\x02\n\x11\x45ventDepositClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x02 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x03 \x01(\x0c\x12\x17\n\x0f\x65thereum_sender\x18\x04 \x01(\t\x12\x17\n\x0f\x63osmos_receiver\x18\x05 \x01(\t\x12\x16\n\x0etoken_contract\x18\x06 \x01(\t\x12>\n\x06\x61mount\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x1c\n\x14orchestrator_address\x18\x08 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\t \x01(\t\"\xa2\x01\n\x12\x45ventWithdrawClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x02 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x03 \x01(\x0c\x12\x13\n\x0b\x62\x61tch_nonce\x18\x04 \x01(\x04\x12\x16\n\x0etoken_contract\x18\x05 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x06 \x01(\t\"\xd8\x01\n\x17\x45ventERC20DeployedClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x02 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x03 \x01(\x0c\x12\x14\n\x0c\x63osmos_denom\x18\x04 \x01(\t\x12\x16\n\x0etoken_contract\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0e\n\x06symbol\x18\x07 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x08 \x01(\x04\x12\x1c\n\x14orchestrator_address\x18\t \x01(\t\"\xa9\x02\n\x16\x45ventValsetUpdateClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x02 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x03 \x01(\x0c\x12\x14\n\x0cvalset_nonce\x18\x04 \x01(\x04\x12;\n\x0evalset_members\x18\x05 \x03(\x0b\x32#.injective.peggy.v1.BridgeValidator\x12\x45\n\rreward_amount\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x14\n\x0creward_token\x18\x07 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x08 \x01(\t\".\n\x14\x45ventCancelSendToEth\x12\x16\n\x0eoutgoing_tx_id\x18\x01 \x01(\x04\"_\n\x1f\x45ventSubmitBadSignatureEvidence\x12\x19\n\x11\x62\x61\x64_eth_signature\x18\x01 \x01(\t\x12!\n\x19\x62\x61\x64_eth_signature_subject\x18\x02 \x01(\tBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.peggy.v1.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types'
  _EVENTVALSETUPDATEREQUEST.fields_by_name['reward_amount']._options = None
  _EVENTVALSETUPDATEREQUEST.fields_by_name['reward_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _EVENTSENDTOETH.fields_by_name['amount']._options = None
  _EVENTSENDTOETH.fields_by_name['amount']._serialized_options = b'\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin\310\336\037\000'
  _EVENTSENDTOETH.fields_by_name['bridge_fee']._options = None
  _EVENTSENDTOETH.fields_by_name['bridge_fee']._serialized_options = b'\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin\310\336\037\000'
  _EVENTDEPOSITCLAIM.fields_by_name['amount']._options = None
  _EVENTDEPOSITCLAIM.fields_by_name['amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _EVENTVALSETUPDATECLAIM.fields_by_name['reward_amount']._options = None
  _EVENTVALSETUPDATECLAIM.fields_by_name['reward_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _EVENTATTESTATIONOBSERVED._serialized_start=148
  _EVENTATTESTATIONOBSERVED._serialized_end=320
  _EVENTBRIDGEWITHDRAWCANCELED._serialized_start=322
  _EVENTBRIDGEWITHDRAWCANCELED._serialized_end=401
  _EVENTOUTGOINGBATCH._serialized_start=404
  _EVENTOUTGOINGBATCH._serialized_end=535
  _EVENTOUTGOINGBATCHCANCELED._serialized_start=537
  _EVENTOUTGOINGBATCHCANCELED._serialized_end=648
  _EVENTVALSETUPDATEREQUEST._serialized_start=651
  _EVENTVALSETUPDATEREQUEST._serialized_end=876
  _EVENTSETORCHESTRATORADDRESSES._serialized_start=878
  _EVENTSETORCHESTRATORADDRESSES._serialized_end=996
  _EVENTVALSETCONFIRM._serialized_start=998
  _EVENTVALSETCONFIRM._serialized_end=1070
  _EVENTSENDTOETH._serialized_start=1073
  _EVENTSENDTOETH._serialized_end=1281
  _EVENTCONFIRMBATCH._serialized_start=1283
  _EVENTCONFIRMBATCH._serialized_end=1353
  _EVENTATTESTATIONVOTE._serialized_start=1355
  _EVENTATTESTATIONVOTE._serialized_end=1437
  _EVENTDEPOSITCLAIM._serialized_start=1440
  _EVENTDEPOSITCLAIM._serialized_end=1708
  _EVENTWITHDRAWCLAIM._serialized_start=1711
  _EVENTWITHDRAWCLAIM._serialized_end=1873
  _EVENTERC20DEPLOYEDCLAIM._serialized_start=1876
  _EVENTERC20DEPLOYEDCLAIM._serialized_end=2092
  _EVENTVALSETUPDATECLAIM._serialized_start=2095
  _EVENTVALSETUPDATECLAIM._serialized_end=2392
  _EVENTCANCELSENDTOETH._serialized_start=2394
  _EVENTCANCELSENDTOETH._serialized_end=2440
  _EVENTSUBMITBADSIGNATUREEVIDENCE._serialized_start=2442
  _EVENTSUBMITBADSIGNATUREEVIDENCE._serialized_end=2537
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/p2p/conn.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from tendermint.crypto import keys_pb2 as tendermint_dot_crypto_dot_keys__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19tendermint/p2p/conn.proto\x12\x0etendermint.p2p\x1a\x14gogoproto/gogo.proto\x1a\x1ctendermint/crypto/keys.proto\"\x0c\n\nPacketPing\"\x0c\n\nPacketPong\"R\n\tPacketMsg\x12!\n\nchannel_id\x18\x01 \x01(\x05\x42\r\xe2\xde\x1f\tChannelID\x12\x14\n\x03\x65of\x18\x02 \x01(\x08\x42\x07\xe2\xde\x1f\x03\x45OF\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"\xa6\x01\n\x06Packet\x12\x31\n\x0bpacket_ping\x18\x01 \x01(\x0b\x32\x1a.tendermint.p2p.PacketPingH\x00\x12\x31\n\x0bpacket_pong\x18\x02 \x01(\x0b\x32\x1a.tendermint.p2p.PacketPongH\x00\x12/\n\npacket_msg\x18\x03 \x01(\x0b\x32\x19.tendermint.p2p.PacketMsgH\x00\x42\x05\n\x03sum\"R\n\x0e\x41uthSigMessage\x12\x33\n\x07pub_key\x18\x01 \x01(\x0b\x32\x1c.tendermint.crypto.PublicKeyB\x04\xc8\xde\x1f\x00\x12\x0b\n\x03sig\x18\x02 \x01(\x0c\x42\x37Z5github.com/tendermint/tendermint/proto/tendermint/p2pb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.p2p.conn_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/tendermint/tendermint/proto/tendermint/p2p'
  _PACKETMSG.fields_by_name['channel_id']._options = None
  _PACKETMSG.fields_by_name['channel_id']._serialized_options = b'\342\336\037\tChannelID'
  _PACKETMSG.fields_by_name['eof']._options = None
  _PACKETMSG.fields_by_name['eof']._serialized_options = b'\342\336\037\003EOF'
  _AUTHSIGMESSAGE.fields_by_name['pub_key']._options = None
  _AUTHSIGMESSAGE.fields_by_name['pub_key']._serialized_options = b'\310\336\037\000'
  _PACKETPING._serialized_start=97
  _PACKETPING._serialized_end=109
  _PACKETPONG._serialized_start=111
  _PACKETPONG._serialized_end=123
  _PACKETMSG._serialized_start=125
  _PACKETMSG._serialized_end=207
  _PACKET._serialized_start=210
  _PACKET._serialized_end=376
  _AUTHSIGMESSAGE._serialized_start=378
  _AUTHSIGMESSAGE._serialized_end=460
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/mempool/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1etendermint/mempool/types.proto\x12\x12tendermint.mempool\"\x12\n\x03Txs\x12\x0b\n\x03txs\x18\x01 \x03(\x0c\"8\n\x07Message\x12&\n\x03txs\x18\x01 \x01(\x0b\x32\x17.tendermint.mempool.TxsH\x00\x42\x05\n\x03sumB;Z9github.com/tendermint/tendermint/proto/tendermint/mempoolb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.mempool.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/tendermint/tendermint/proto/tendermint/mempool'
  _TXS._serialized_start=54
  _TXS._serialized_end=72
  _MESSAGE._serialized_start=74
  _MESSAGE._serialized_end=130
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/abci/v1beta1/abci.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from tendermint.abci import types_pb2 as tendermint_dot_abci_dot_types__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/base/abci/v1beta1/abci.proto\x12\x18\x63osmos.base.abci.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1btendermint/abci/types.proto\x1a\x19google/protobuf/any.proto\"\xe6\x02\n\nTxResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\x1a\n\x06txhash\x18\x02 \x01(\tB\n\xe2\xde\x1f\x06TxHash\x12\x11\n\tcodespace\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\t\x12\x0f\n\x07raw_log\x18\x06 \x01(\t\x12O\n\x04logs\x18\x07 \x03(\x0b\x32(.cosmos.base.abci.v1beta1.ABCIMessageLogB\x17\xaa\xdf\x1f\x0f\x41\x42\x43IMessageLogs\xc8\xde\x1f\x00\x12\x0c\n\x04info\x18\x08 \x01(\t\x12\x12\n\ngas_wanted\x18\t \x01(\x03\x12\x10\n\x08gas_used\x18\n \x01(\x03\x12 \n\x02tx\x18\x0b \x01(\x0b\x32\x14.google.protobuf.Any\x12\x11\n\ttimestamp\x18\x0c \x01(\t\x12,\n\x06\x65vents\x18\r \x03(\x0b\x32\x16.tendermint.abci.EventB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"\x83\x01\n\x0e\x41\x42\x43IMessageLog\x12\x11\n\tmsg_index\x18\x01 \x01(\r\x12\x0b\n\x03log\x18\x02 \x01(\t\x12K\n\x06\x65vents\x18\x03 \x03(\x0b\x32%.cosmos.base.abci.v1beta1.StringEventB\x14\xaa\xdf\x1f\x0cStringEvents\xc8\xde\x1f\x00:\x04\x80\xdc \x01\"`\n\x0bStringEvent\x12\x0c\n\x04type\x18\x01 \x01(\t\x12=\n\nattributes\x18\x02 \x03(\x0b\x32#.cosmos.base.abci.v1beta1.AttributeB\x04\xc8\xde\x1f\x00:\x04\x80\xdc \x01\"\'\n\tAttribute\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"[\n\x07GasInfo\x12)\n\ngas_wanted\x18\x01 \x01(\x04\x42\x15\xf2\xde\x1f\x11yaml:\"gas_wanted\"\x12%\n\x08gas_used\x18\x02 \x01(\x04\x42\x13\xf2\xde\x1f\x0fyaml:\"gas_used\"\"W\n\x06Result\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0b\n\x03log\x18\x02 \x01(\t\x12,\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x16.tendermint.abci.EventB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"\x85\x01\n\x12SimulationResponse\x12=\n\x08gas_info\x18\x01 \x01(\x0b\x32!.cosmos.base.abci.v1beta1.GasInfoB\x08\xd0\xde\x1f\x01\xc8\xde\x1f\x00\x12\x30\n\x06result\x18\x02 \x01(\x0b\x32 .cosmos.base.abci.v1beta1.Result\"/\n\x07MsgData\x12\x10\n\x08msg_type\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c:\x04\x80\xdc \x01\"B\n\tTxMsgData\x12/\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32!.cosmos.base.abci.v1beta1.MsgData:\x04\x80\xdc \x01\"\x99\x02\n\x0fSearchTxsResult\x12:\n\x0btotal_count\x18\x01 \x01(\x04\x42%\xf2\xde\x1f\x12yaml:\"total_count\"\xea\xde\x1f\x0btotal_count\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\x12:\n\x0bpage_number\x18\x03 \x01(\x04\x42%\xf2\xde\x1f\x12yaml:\"page_number\"\xea\xde\x1f\x0bpage_number\x12\x37\n\npage_total\x18\x04 \x01(\x04\x42#\xf2\xde\x1f\x11yaml:\"page_total\"\xea\xde\x1f\npage_total\x12\r\n\x05limit\x18\x05 \x01(\x04\x12\x31\n\x03txs\x18\x06 \x03(\x0b\x32$.cosmos.base.abci.v1beta1.TxResponse:\x04\x80\xdc \x01\x42(Z\"github.com/cosmos/cosmos-sdk/types\xd8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.abci.v1beta1.abci_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\"github.com/cosmos/cosmos-sdk/types\330\341\036\000'
  _TXRESPONSE.fields_by_name['txhash']._options = None
  _TXRESPONSE.fields_by_name['txhash']._serialized_options = b'\342\336\037\006TxHash'
  _TXRESPONSE.fields_by_name['logs']._options = None
  _TXRESPONSE.fields_by_name['logs']._serialized_options = b'\252\337\037\017ABCIMessageLogs\310\336\037\000'
  _TXRESPONSE.fields_by_name['events']._options = None
  _TXRESPONSE.fields_by_name['events']._serialized_options = b'\310\336\037\000'
  _TXRESPONSE._options = None
  _TXRESPONSE._serialized_options = b'\210\240\037\000'
  _ABCIMESSAGELOG.fields_by_name['events']._options = None
  _ABCIMESSAGELOG.fields_by_name['events']._serialized_options = b'\252\337\037\014StringEvents\310\336\037\000'
  _ABCIMESSAGELOG._options = None
  _ABCIMESSAGELOG._serialized_options = b'\200\334 \001'
  _STRINGEVENT.fields_by_name['attributes']._options = None
  _STRINGEVENT.fields_by_name['attributes']._serialized_options = b'\310\336\037\000'
  _STRINGEVENT._options = None
  _STRINGEVENT._serialized_options = b'\200\334 \001'
  _GASINFO.fields_by_name['gas_wanted']._options = None
  _GASINFO.fields_by_name['gas_wanted']._serialized_options = b'\362\336\037\021yaml:\"gas_wanted\"'
  _GASINFO.fields_by_name['gas_used']._options = None
  _GASINFO.fields_by_name['gas_used']._serialized_options = b'\362\336\037\017yaml:\"gas_used\"'
  _RESULT.fields_by_name['events']._options = None
  _RESULT.fields_by_name['events']._serialized_options = b'\310\336\037\000'
  _RESULT._options = None
  _RESULT._serialized_options = b'\210\240\037\000'
  _SIMULATIONRESPONSE.fields_by_name['gas_info']._options = None
  _SIMULATIONRESPONSE.fields_by_name['gas_info']._serialized_options = b'\320\336\037\001\310\336\037\000'
  _MSGDATA._options = None
  _MSGDATA._serialized_options = b'\200\334 \001'
  _TXMSGDATA._options = None
  _TXMSGDATA._serialized_options = b'\200\334 \001'
  _SEARCHTXSRESULT.fields_by_name['total_count']._options = None
  _SEARCHTXSRESULT.fields_by_name['total_count']._serialized_options = b'\362\336\037\022yaml:\"total_count\"\352\336\037\013total_count'
  _SEARCHTXSRESULT.fields_by_name['page_number']._options = None
  _SEARCHTXSRESULT.fields_by_name['page_number']._serialized_options = b'\362\336\037\022yaml:\"page_number\"\352\336\037\013page_number'
  _SEARCHTXSRESULT.fields_by_name['page_total']._options = None
  _SEARCHTXSRESULT.fields_by_name['page_total']._serialized_options = b'\362\336\037\021yaml:\"page_total\"\352\336\037\npage_total'
  _SEARCHTXSRESULT._options = None
  _SEARCHTXSRESULT._serialized_options = b'\200\334 \001'
  _TXRESPONSE._serialized_start=144
  _TXRESPONSE._serialized_end=502
  _ABCIMESSAGELOG._serialized_start=505
  _ABCIMESSAGELOG._serialized_end=636
  _STRINGEVENT._serialized_start=638
  _STRINGEVENT._serialized_end=734
  _ATTRIBUTE._serialized_start=736
  _ATTRIBUTE._serialized_end=775
  _GASINFO._serialized_start=777
  _GASINFO._serialized_end=868
  _RESULT._serialized_start=870
  _RESULT._serialized_end=957
  _SIMULATIONRESPONSE._serialized_start=960
  _SIMULATIONRESPONSE._serialized_end=1093
  _MSGDATA._serialized_start=1095
  _MSGDATA._serialized_end=1142
  _TXMSGDATA._serialized_start=1144
  _TXMSGDATA._serialized_end=1210
  _SEARCHTXSRESULT._serialized_start=1213
  _SEARCHTXSRESULT._serialized_end=1494
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: confio/proofs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63onfio/proofs.proto\x12\x05ics23\"g\n\x0e\x45xistenceProof\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x1b\n\x04leaf\x18\x03 \x01(\x0b\x32\r.ics23.LeafOp\x12\x1c\n\x04path\x18\x04 \x03(\x0b\x32\x0e.ics23.InnerOp\"k\n\x11NonExistenceProof\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12#\n\x04left\x18\x02 \x01(\x0b\x32\x15.ics23.ExistenceProof\x12$\n\x05right\x18\x03 \x01(\x0b\x32\x15.ics23.ExistenceProof\"\xc7\x01\n\x0f\x43ommitmentProof\x12&\n\x05\x65xist\x18\x01 \x01(\x0b\x32\x15.ics23.ExistenceProofH\x00\x12,\n\x08nonexist\x18\x02 \x01(\x0b\x32\x18.ics23.NonExistenceProofH\x00\x12\"\n\x05\x62\x61tch\x18\x03 \x01(\x0b\x32\x11.ics23.BatchProofH\x00\x12\x31\n\ncompressed\x18\x04 \x01(\x0b\x32\x1b.ics23.CompressedBatchProofH\x00\x42\x07\n\x05proof\"\xa0\x01\n\x06LeafOp\x12\x1b\n\x04hash\x18\x01 \x01(\x0e\x32\r.ics23.HashOp\x12\"\n\x0bprehash_key\x18\x02 \x01(\x0e\x32\r.ics23.HashOp\x12$\n\rprehash_value\x18\x03 \x01(\x0e\x32\r.ics23.HashOp\x12\x1f\n\x06length\x18\x04 \x01(\x0e\x32\x0f.ics23.LengthOp\x12\x0e\n\x06prefix\x18\x05 \x01(\x0c\"F\n\x07InnerOp\x12\x1b\n\x04hash\x18\x01 \x01(\x0e\x32\r.ics23.HashOp\x12\x0e\n\x06prefix\x18\x02 \x01(\x0c\x12\x0e\n\x06suffix\x18\x03 \x01(\x0c\"y\n\tProofSpec\x12 \n\tleaf_spec\x18\x01 \x01(\x0b\x32\r.ics23.LeafOp\x12$\n\ninner_spec\x18\x02 \x01(\x0b\x32\x10.ics23.InnerSpec\x12\x11\n\tmax_depth\x18\x03 \x01(\x05\x12\x11\n\tmin_depth\x18\x04 \x01(\x05\"\x9c\x01\n\tInnerSpec\x12\x13\n\x0b\x63hild_order\x18\x01 \x03(\x05\x12\x12\n\nchild_size\x18\x02 \x01(\x05\x12\x19\n\x11min_prefix_length\x18\x03 \x01(\x05\x12\x19\n\x11max_prefix_length\x18\x04 \x01(\x05\x12\x13\n\x0b\x65mpty_child\x18\x05 \x01(\x0c\x12\x1b\n\x04hash\x18\x06 \x01(\x0e\x32\r.ics23.HashOp\"0\n\nBatchProof\x12\"\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x11.ics23.BatchEntry\"k\n\nBatchEntry\x12&\n\x05\x65xist\x18\x01 \x01(\x0b\x32\x15.ics23.ExistenceProofH\x00\x12,\n\x08nonexist\x18\x02 \x01(\x0b\x32\x18.ics23.NonExistenceProofH\x00\x42\x07\n\x05proof\"k\n\x14\x43ompressedBatchProof\x12,\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1b.ics23.CompressedBatchEntry\x12%\n\rlookup_inners\x18\x02 \x03(\x0b\x32\x0e.ics23.InnerOp\"\x89\x01\n\x14\x43ompressedBatchEntry\x12\x30\n\x05\x65xist\x18\x01 \x01(\x0b\x32\x1f.ics23.CompressedExistenceProofH\x00\x12\x36\n\x08nonexist\x18\x02 \x01(\x0b\x32\".ics23.CompressedNonExistenceProofH\x00\x42\x07\n\x05proof\"a\n\x18\x43ompressedExistenceProof\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x1b\n\x04leaf\x18\x03 \x01(\x0b\x32\r.ics23.LeafOp\x12\x0c\n\x04path\x18\x04 \x03(\x05\"\x89\x01\n\x1b\x43ompressedNonExistenceProof\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12-\n\x04left\x18\x02 \x01(\x0b\x32\x1f.ics23.CompressedExistenceProof\x12.\n\x05right\x18\x03 \x01(\x0b\x32\x1f.ics23.CompressedExistenceProof*U\n\x06HashOp\x12\x0b\n\x07NO_HASH\x10\x00\x12\n\n\x06SHA256\x10\x01\x12\n\n\x06SHA512\x10\x02\x12\n\n\x06KECCAK\x10\x03\x12\r\n\tRIPEMD160\x10\x04\x12\x0b\n\x07\x42ITCOIN\x10\x05*\xab\x01\n\x08LengthOp\x12\r\n\tNO_PREFIX\x10\x00\x12\r\n\tVAR_PROTO\x10\x01\x12\x0b\n\x07VAR_RLP\x10\x02\x12\x0f\n\x0b\x46IXED32_BIG\x10\x03\x12\x12\n\x0e\x46IXED32_LITTLE\x10\x04\x12\x0f\n\x0b\x46IXED64_BIG\x10\x05\x12\x12\n\x0e\x46IXED64_LITTLE\x10\x06\x12\x14\n\x10REQUIRE_32_BYTES\x10\x07\x12\x14\n\x10REQUIRE_64_BYTES\x10\x08\x42\x1cZ\x1agithub.com/confio/ics23/gob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'confio.proofs_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\032github.com/confio/ics23/go'
  _HASHOP._serialized_start=1610
  _HASHOP._serialized_end=1695
  _LENGTHOP._serialized_start=1698
  _LENGTHOP._serialized_end=1869
  _EXISTENCEPROOF._serialized_start=30
  _EXISTENCEPROOF._serialized_end=133
  _NONEXISTENCEPROOF._serialized_start=135
  _NONEXISTENCEPROOF._serialized_end=242
  _COMMITMENTPROOF._serialized_start=245
  _COMMITMENTPROOF._serialized_end=444
  _LEAFOP._serialized_start=447
  _LEAFOP._serialized_end=607
  _INNEROP._serialized_start=609
  _INNEROP._serialized_end=679
  _PROOFSPEC._serialized_start=681
  _PROOFSPEC._serialized_end=802
  _INNERSPEC._serialized_start=805
  _INNERSPEC._serialized_end=961
  _BATCHPROOF._serialized_start=963
  _BATCHPROOF._serialized_end=1011
  _BATCHENTRY._serialized_start=1013
  _BATCHENTRY._serialized_end=1120
  _COMPRESSEDBATCHPROOF._serialized_start=1122
  _COMPRESSEDBATCHPROOF._serialized_end=1229
  _COMPRESSEDBATCHENTRY._serialized_start=1232
  _COMPRESSEDBATCHENTRY._serialized_end=1369
  _COMPRESSEDEXISTENCEPROOF._serialized_start=1371
  _COMPRESSEDEXISTENCEPROOF._serialized_end=1468
  _COMPRESSEDNONEXISTENCEPROOF._serialized_start=1471
  _COMPRESSEDNONEXISTENCEPROOF._serialized_end=1608
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/types/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dtendermint/types/events.proto\x12\x10tendermint.types\"B\n\x13\x45ventDataRoundState\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12\x0c\n\x04step\x18\x03 \x01(\tB9Z7github.com/tendermint/tendermint/proto/tendermint/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.types.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/tendermint/tendermint/proto/tendermint/types'
  _EVENTDATAROUNDSTATE._serialized_start=51
  _EVENTDATAROUNDSTATE._serialized_end=117
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/auction/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from injective.auction.v1beta1 import auction_pb2 as injective_dot_auction_dot_v1beta1_dot_auction__pb2
from injective.auction.v1beta1 import genesis_pb2 as injective_dot_auction_dot_v1beta1_dot_genesis__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%injective/auction/v1beta1/query.proto\x12\x19injective.auction.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\'injective/auction/v1beta1/auction.proto\x1a\'injective/auction/v1beta1/genesis.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x1b\n\x19QueryAuctionParamsRequest\"U\n\x1aQueryAuctionParamsResponse\x12\x37\n\x06params\x18\x01 \x01(\x0b\x32!.injective.auction.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\"\"\n QueryCurrentAuctionBasketRequest\"\x93\x02\n!QueryCurrentAuctionBasketResponse\x12[\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xc8\xde\x1f\x00\x12\x14\n\x0c\x61uctionRound\x18\x02 \x01(\x04\x12\x1a\n\x12\x61uctionClosingTime\x18\x03 \x01(\x03\x12\x15\n\rhighestBidder\x18\x04 \x01(\t\x12H\n\x10highestBidAmount\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"\x19\n\x17QueryModuleStateRequest\"R\n\x18QueryModuleStateResponse\x12\x36\n\x05state\x18\x01 \x01(\x0b\x32\'.injective.auction.v1beta1.GenesisState2\xa1\x04\n\x05Query\x12\xa7\x01\n\rAuctionParams\x12\x34.injective.auction.v1beta1.QueryAuctionParamsRequest\x1a\x35.injective.auction.v1beta1.QueryAuctionParamsResponse\")\x82\xd3\xe4\x93\x02#\x12!/injective/auction/v1beta1/params\x12\xbc\x01\n\x14\x43urrentAuctionBasket\x12;.injective.auction.v1beta1.QueryCurrentAuctionBasketRequest\x1a<.injective.auction.v1beta1.QueryCurrentAuctionBasketResponse\")\x82\xd3\xe4\x93\x02#\x12!/injective/auction/v1beta1/basket\x12\xae\x01\n\x12\x41uctionModuleState\x12\x32.injective.auction.v1beta1.QueryModuleStateRequest\x1a\x33.injective.auction.v1beta1.QueryModuleStateResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/injective/auction/v1beta1/module_stateBOZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.auction.v1beta1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/types'
  _QUERYAUCTIONPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYAUCTIONPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYCURRENTAUCTIONBASKETRESPONSE.fields_by_name['amount']._options = None
  _QUERYCURRENTAUCTIONBASKETRESPONSE.fields_by_name['amount']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\310\336\037\000'
  _QUERYCURRENTAUCTIONBASKETRESPONSE.fields_by_name['highestBidAmount']._options = None
  _QUERYCURRENTAUCTIONBASKETRESPONSE.fields_by_name['highestBidAmount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _QUERY.methods_by_name['AuctionParams']._options = None
  _QUERY.methods_by_name['AuctionParams']._serialized_options = b'\202\323\344\223\002#\022!/injective/auction/v1beta1/params'
  _QUERY.methods_by_name['CurrentAuctionBasket']._options = None
  _QUERY.methods_by_name['CurrentAuctionBasket']._serialized_options = b'\202\323\344\223\002#\022!/injective/auction/v1beta1/basket'
  _QUERY.methods_by_name['AuctionModuleState']._options = None
  _QUERY.methods_by_name['AuctionModuleState']._serialized_options = b'\202\323\344\223\002)\022\'/injective/auction/v1beta1/module_state'
  _QUERYAUCTIONPARAMSREQUEST._serialized_start=234
  _QUERYAUCTIONPARAMSREQUEST._serialized_end=261
  _QUERYAUCTIONPARAMSRESPONSE._serialized_start=263
  _QUERYAUCTIONPARAMSRESPONSE._serialized_end=348
  _QUERYCURRENTAUCTIONBASKETREQUEST._serialized_start=350
  _QUERYCURRENTAUCTIONBASKETREQUEST._serialized_end=384
  _QUERYCURRENTAUCTIONBASKETRESPONSE._serialized_start=387
  _QUERYCURRENTAUCTIONBASKETRESPONSE._serialized_end=662
  _QUERYMODULESTATEREQUEST._serialized_start=664
  _QUERYMODULESTATEREQUEST._serialized_end=689
  _QUERYMODULESTATERESPONSE._serialized_start=691
  _QUERYMODULESTATERESPONSE._serialized_end=773
  _QUERY._serialized_start=776
  _QUERY._serialized_end=1321
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/types/v1beta1/account.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%injective/types/v1beta1/account.proto\x12\x17injective.types.v1beta1\x1a\x1e\x63osmos/auth/v1beta1/auth.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\"\xce\x01\n\nEthAccount\x12S\n\x0c\x62\x61se_account\x18\x01 \x01(\x0b\x32 .cosmos.auth.v1beta1.BaseAccountB\x1b\xd0\xde\x1f\x01\xf2\xde\x1f\x13yaml:\"base_account\"\x12\'\n\tcode_hash\x18\x02 \x01(\x0c\x42\x14\xf2\xde\x1f\x10yaml:\"code_hash\":B\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\xd2\xb4-2github.com/cosmos/cosmos-sdk/x/auth/types.AccountIB?Z=github.com/InjectiveLabs/injective-core/injective-chain/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.types.v1beta1.account_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z=github.com/InjectiveLabs/injective-core/injective-chain/types'
  _ETHACCOUNT.fields_by_name['base_account']._options = None
  _ETHACCOUNT.fields_by_name['base_account']._serialized_options = b'\320\336\037\001\362\336\037\023yaml:\"base_account\"'
  _ETHACCOUNT.fields_by_name['code_hash']._options = None
  _ETHACCOUNT.fields_by_name['code_hash']._serialized_options = b'\362\336\037\020yaml:\"code_hash\"'
  _ETHACCOUNT._options = None
  _ETHACCOUNT._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000\322\264-2github.com/cosmos/cosmos-sdk/x/auth/types.AccountI'
  _ETHACCOUNT._serialized_start=148
  _ETHACCOUNT._serialized_end=354
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/ocr/v1beta1/ocr.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1finjective/ocr/v1beta1/ocr.proto\x12\x15injective.ocr.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"W\n\x06Params\x12\x12\n\nlink_denom\x18\x01 \x01(\t\x12\x1d\n\x15payout_block_interval\x18\x02 \x01(\x04\x12\x14\n\x0cmodule_admin\x18\x03 \x01(\t:\x04\xe8\xa0\x1f\x01\"\xcc\x01\n\nFeedConfig\x12\x0f\n\x07signers\x18\x01 \x03(\t\x12\x14\n\x0ctransmitters\x18\x02 \x03(\t\x12\t\n\x01\x66\x18\x03 \x01(\r\x12\x16\n\x0eonchain_config\x18\x04 \x01(\x0c\x12\x1f\n\x17offchain_config_version\x18\x05 \x01(\x04\x12\x17\n\x0foffchain_config\x18\x06 \x01(\x0c\x12:\n\rmodule_params\x18\x07 \x01(\x0b\x32#.injective.ocr.v1beta1.ModuleParams\"~\n\x0e\x46\x65\x65\x64\x43onfigInfo\x12\x1c\n\x14latest_config_digest\x18\x01 \x01(\x0c\x12\t\n\x01\x66\x18\x02 \x01(\r\x12\t\n\x01n\x18\x03 \x01(\r\x12\x14\n\x0c\x63onfig_count\x18\x04 \x01(\x04\x12\"\n\x1alatest_config_block_number\x18\x05 \x01(\x03\"\xb0\x03\n\x0cModuleParams\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12\x42\n\nmin_answer\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x42\n\nmax_answer\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12L\n\x14link_per_observation\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12M\n\x15link_per_transmission\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x12\n\nlink_denom\x18\x06 \x01(\t\x12\x16\n\x0eunique_reports\x18\x07 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x12\n\nfeed_admin\x18\t \x01(\t\x12\x15\n\rbilling_admin\x18\n \x01(\t\"\xaa\x01\n\x0e\x43ontractConfig\x12\x14\n\x0c\x63onfig_count\x18\x01 \x01(\x04\x12\x0f\n\x07signers\x18\x02 \x03(\t\x12\x14\n\x0ctransmitters\x18\x03 \x03(\t\x12\t\n\x01\x66\x18\x04 \x01(\r\x12\x16\n\x0eonchain_config\x18\x05 \x01(\x0c\x12\x1f\n\x17offchain_config_version\x18\x06 \x01(\x04\x12\x17\n\x0foffchain_config\x18\x07 \x01(\x0c\"t\n\x11SetConfigProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x31\n\x06\x63onfig\x18\x03 \x01(\x0b\x32!.injective.ocr.v1beta1.FeedConfig:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xd0\x03\n\x0e\x46\x65\x65\x64Properties\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12\t\n\x01\x66\x18\x02 \x01(\r\x12\x16\n\x0eonchain_config\x18\x03 \x01(\x0c\x12\x1f\n\x17offchain_config_version\x18\x04 \x01(\x04\x12\x17\n\x0foffchain_config\x18\x05 \x01(\x0c\x12\x42\n\nmin_answer\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x42\n\nmax_answer\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12L\n\x14link_per_observation\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12M\n\x15link_per_transmission\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x16\n\x0eunique_reports\x18\n \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x0b \x01(\t\"\xc1\x01\n\x16SetBatchConfigProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07signers\x18\x03 \x03(\t\x12\x14\n\x0ctransmitters\x18\x04 \x03(\t\x12\x12\n\nlink_denom\x18\x05 \x01(\t\x12>\n\x0f\x66\x65\x65\x64_properties\x18\x06 \x03(\x0b\x32%.injective.ocr.v1beta1.FeedProperties:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"*\n\x18OracleObservationsCounts\x12\x0e\n\x06\x63ounts\x18\x01 \x03(\r\"F\n\x11GasReimbursements\x12\x31\n\x0ereimbursements\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.Coin\"7\n\x05Payee\x12\x18\n\x10transmitter_addr\x18\x01 \x01(\t\x12\x14\n\x0cpayment_addr\x18\x02 \x01(\t\"\x8e\x01\n\x0cTransmission\x12>\n\x06\x61nswer\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x1e\n\x16observations_timestamp\x18\x02 \x01(\x03\x12\x1e\n\x16transmission_timestamp\x18\x03 \x01(\x03\"-\n\rEpochAndRound\x12\r\n\x05\x65poch\x18\x01 \x01(\x04\x12\r\n\x05round\x18\x02 \x01(\x04\"\x81\x01\n\x06Report\x12\x1e\n\x16observations_timestamp\x18\x01 \x01(\x03\x12\x11\n\tobservers\x18\x02 \x01(\x0c\x12\x44\n\x0cobservations\x18\x03 \x03(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"g\n\x0cReportToSign\x12\x15\n\rconfig_digest\x18\x01 \x01(\x0c\x12\r\n\x05\x65poch\x18\x02 \x01(\x04\x12\r\n\x05round\x18\x03 \x01(\x04\x12\x12\n\nextra_hash\x18\x04 \x01(\x0c\x12\x0e\n\x06report\x18\x05 \x01(\x0c\"p\n\x0f\x45ventOraclePaid\x12\x18\n\x10transmitter_addr\x18\x01 \x01(\t\x12\x12\n\npayee_addr\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\xd1\x01\n\x12\x45ventAnswerUpdated\x12?\n\x07\x63urrent\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12@\n\x08round_id\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x38\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\x90\xdf\x1f\x01\xc8\xde\x1f\x00\"\x9f\x01\n\rEventNewRound\x12@\n\x08round_id\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x12\n\nstarted_by\x18\x02 \x01(\t\x12\x38\n\nstarted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\x90\xdf\x1f\x01\xc8\xde\x1f\x00\"8\n\x10\x45ventTransmitted\x12\x15\n\rconfig_digest\x18\x01 \x01(\x0c\x12\r\n\x05\x65poch\x18\x02 \x01(\x04\"\xe8\x02\n\x14\x45ventNewTransmission\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12\x1b\n\x13\x61ggregator_round_id\x18\x02 \x01(\r\x12>\n\x06\x61nswer\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x13\n\x0btransmitter\x18\x04 \x01(\t\x12\x1e\n\x16observations_timestamp\x18\x05 \x01(\x03\x12\x44\n\x0cobservations\x18\x06 \x03(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x11\n\tobservers\x18\x07 \x01(\x0c\x12\x15\n\rconfig_digest\x18\x08 \x01(\x0c\x12=\n\x0f\x65poch_and_round\x18\t \x01(\x0b\x32$.injective.ocr.v1beta1.EpochAndRound\"\xbc\x01\n\x0e\x45ventConfigSet\x12\x15\n\rconfig_digest\x18\x01 \x01(\x0c\x12$\n\x1cprevious_config_block_number\x18\x02 \x01(\x03\x12\x31\n\x06\x63onfig\x18\x03 \x01(\x0b\x32!.injective.ocr.v1beta1.FeedConfig\x12:\n\x0b\x63onfig_info\x18\x04 \x01(\x0b\x32%.injective.ocr.v1beta1.FeedConfigInfoBKZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.ocr.v1beta1.ocr_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\350\240\037\001'
  _MODULEPARAMS.fields_by_name['min_answer']._options = None
  _MODULEPARAMS.fields_by_name['min_answer']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MODULEPARAMS.fields_by_name['max_answer']._options = None
  _MODULEPARAMS.fields_by_name['max_answer']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MODULEPARAMS.fields_by_name['link_per_observation']._options = None
  _MODULEPARAMS.fields_by_name['link_per_observation']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _MODULEPARAMS.fields_by_name['link_per_transmission']._options = None
  _MODULEPARAMS.fields_by_name['link_per_transmission']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _SETCONFIGPROPOSAL._options = None
  _SETCONFIGPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _FEEDPROPERTIES.fields_by_name['min_answer']._options = None
  _FEEDPROPERTIES.fields_by_name['min_answer']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _FEEDPROPERTIES.fields_by_name['max_answer']._options = None
  _FEEDPROPERTIES.fields_by_name['max_answer']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _FEEDPROPERTIES.fields_by_name['link_per_observation']._options = None
  _FEEDPROPERTIES.fields_by_name['link_per_observation']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _FEEDPROPERTIES.fields_by_name['link_per_transmission']._options = None
  _FEEDPROPERTIES.fields_by_name['link_per_transmission']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _SETBATCHCONFIGPROPOSAL._options = None
  _SETBATCHCONFIGPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _TRANSMISSION.fields_by_name['answer']._options = None
  _TRANSMISSION.fields_by_name['answer']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _REPORT.fields_by_name['observations']._options = None
  _REPORT.fields_by_name['observations']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _EVENTORACLEPAID.fields_by_name['amount']._options = None
  _EVENTORACLEPAID.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _EVENTANSWERUPDATED.fields_by_name['current']._options = None
  _EVENTANSWERUPDATED.fields_by_name['current']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _EVENTANSWERUPDATED.fields_by_name['round_id']._options = None
  _EVENTANSWERUPDATED.fields_by_name['round_id']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _EVENTANSWERUPDATED.fields_by_name['updated_at']._options = None
  _EVENTANSWERUPDATED.fields_by_name['updated_at']._serialized_options = b'\220\337\037\001\310\336\037\000'
  _EVENTNEWROUND.fields_by_name['round_id']._options = None
  _EVENTNEWROUND.fields_by_name['round_id']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _EVENTNEWROUND.fields_by_name['started_at']._options = None
  _EVENTNEWROUND.fields_by_name['started_at']._serialized_options = b'\220\337\037\001\310\336\037\000'
  _EVENTNEWTRANSMISSION.fields_by_name['answer']._options = None
  _EVENTNEWTRANSMISSION.fields_by_name['answer']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _EVENTNEWTRANSMISSION.fields_by_name['observations']._options = None
  _EVENTNEWTRANSMISSION.fields_by_name['observations']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS._serialized_start=145
  _PARAMS._serialized_end=232
  _FEEDCONFIG._serialized_start=235
  _FEEDCONFIG._serialized_end=439
  _FEEDCONFIGINFO._serialized_start=441
  _FEEDCONFIGINFO._serialized_end=567
  _MODULEPARAMS._serialized_start=570
  _MODULEPARAMS._serialized_end=1002
  _CONTRACTCONFIG._serialized_start=1005
  _CONTRACTCONFIG._serialized_end=1175
  _SETCONFIGPROPOSAL._serialized_start=1177
  _SETCONFIGPROPOSAL._serialized_end=1293
  _FEEDPROPERTIES._serialized_start=1296
  _FEEDPROPERTIES._serialized_end=1760
  _SETBATCHCONFIGPROPOSAL._serialized_start=1763
  _SETBATCHCONFIGPROPOSAL._serialized_end=1956
  _ORACLEOBSERVATIONSCOUNTS._serialized_start=1958
  _ORACLEOBSERVATIONSCOUNTS._serialized_end=2000
  _GASREIMBURSEMENTS._serialized_start=2002
  _GASREIMBURSEMENTS._serialized_end=2072
  _PAYEE._serialized_start=2074
  _PAYEE._serialized_end=2129
  _TRANSMISSION._serialized_start=2132
  _TRANSMISSION._serialized_end=2274
  _EPOCHANDROUND._serialized_start=2276
  _EPOCHANDROUND._serialized_end=2321
  _REPORT._serialized_start=2324
  _REPORT._serialized_end=2453
  _REPORTTOSIGN._serialized_start=2455
  _REPORTTOSIGN._serialized_end=2558
  _EVENTORACLEPAID._serialized_start=2560
  _EVENTORACLEPAID._serialized_end=2672
  _EVENTANSWERUPDATED._serialized_start=2675
  _EVENTANSWERUPDATED._serialized_end=2884
  _EVENTNEWROUND._serialized_start=2887
  _EVENTNEWROUND._serialized_end=3046
  _EVENTTRANSMITTED._serialized_start=3048
  _EVENTTRANSMITTED._serialized_end=3104
  _EVENTNEWTRANSMISSION._serialized_start=3107
  _EVENTNEWTRANSMISSION._serialized_end=3467
  _EVENTCONFIGSET._serialized_start=3470
  _EVENTCONFIGSET._serialized_end=3658
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from exchange import injective_explorer_rpc_pb2 as exchange_dot_injective__explorer__rpc__pb2


class InjectiveExplorerRPCStub(object):
    """ExplorerAPI implements explorer data API for e.g. Blockchain Explorer
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAccountTxs = channel.unary_unary(
                '/injective_explorer_rpc.InjectiveExplorerRPC/GetAccountTxs',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.GetAccountTxsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetAccountTxsResponse.FromString,
                )
        self.GetContractTxs = channel.unary_unary(
                '/injective_explorer_rpc.InjectiveExplorerRPC/GetContractTxs',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.GetContractTxsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetContractTxsResponse.FromString,
                )
        self.GetBlocks = channel.unary_unary(
                '/injective_explorer_rpc.InjectiveExplorerRPC/GetBlocks',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.GetBlocksRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetBlocksResponse.FromString,
                )
        self.GetBlock = channel.unary_unary(
                '/injective_explorer_rpc.InjectiveExplorerRPC/GetBlock',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.GetBlockRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetBlockResponse.FromString,
                )
        self.GetValidators = channel.unary_unary(
                '/injective_explorer_rpc.InjectiveExplorerRPC/GetValidators',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.GetValidatorsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetValidatorsResponse.FromString,
                )
        self.GetValidator = channel.unary_unary(
                '/injective_explorer_rpc.InjectiveExplorerRPC/GetValidator',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.GetValidatorRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetValidatorResponse.FromString,
                )
        self.GetValidatorUptime = channel.unary_unary(
                '/injective_explorer_rpc.InjectiveExplorerRPC/GetValidatorUptime',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.GetValidatorUptimeRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetValidatorUptimeResponse.FromString,
                )
        self.GetTxs = channel.unary_unary(
                '/injective_explorer_rpc.InjectiveExplorerRPC/GetTxs',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.GetTxsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetTxsResponse.FromString,
                )
        self.GetTxByTxHash = channel.unary_unary(
                '/injective_explorer_rpc.InjectiveExplorerRPC/GetTxByTxHash',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.GetTxByTxHashRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetTxByTxHashResponse.FromString,
                )
        self.GetPeggyDepositTxs = channel.unary_unary(
                '/injective_explorer_rpc.InjectiveExplorerRPC/GetPeggyDepositTxs',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.GetPeggyDepositTxsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetPeggyDepositTxsResponse.FromString,
                )
        self.GetPeggyWithdrawalTxs = channel.unary_unary(
                '/injective_explorer_rpc.InjectiveExplorerRPC/GetPeggyWithdrawalTxs',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.GetPeggyWithdrawalTxsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetPeggyWithdrawalTxsResponse.FromString,
                )
        self.GetIBCTransferTxs = channel.unary_unary(
                '/injective_explorer_rpc.InjectiveExplorerRPC/GetIBCTransferTxs',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.GetIBCTransferTxsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetIBCTransferTxsResponse.FromString,
                )
        self.GetWasmCodes = channel.unary_unary(
                '/injective_explorer_rpc.InjectiveExplorerRPC/GetWasmCodes',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.GetWasmCodesRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetWasmCodesResponse.FromString,
                )
        self.GetWasmCodeByID = channel.unary_unary(
                '/injective_explorer_rpc.InjectiveExplorerRPC/GetWasmCodeByID',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.GetWasmCodeByIDRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetWasmCodeByIDResponse.FromString,
                )
        self.GetWasmContracts = channel.unary_unary(
                '/injective_explorer_rpc.InjectiveExplorerRPC/GetWasmContracts',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.GetWasmContractsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetWasmContractsResponse.FromString,
                )
        self.GetWasmContractByAddress = channel.unary_unary(
                '/injective_explorer_rpc.InjectiveExplorerRPC/GetWasmContractByAddress',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.GetWasmContractByAddressRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetWasmContractByAddressResponse.FromString,
                )
        self.GetCw20Balance = channel.unary_unary(
                '/injective_explorer_rpc.InjectiveExplorerRPC/GetCw20Balance',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.GetCw20BalanceRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetCw20BalanceResponse.FromString,
                )
        self.Relayers = channel.unary_unary(
                '/injective_explorer_rpc.InjectiveExplorerRPC/Relayers',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.RelayersRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.RelayersResponse.FromString,
                )
        self.StreamTxs = channel.unary_stream(
                '/injective_explorer_rpc.InjectiveExplorerRPC/StreamTxs',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.StreamTxsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.StreamTxsResponse.FromString,
                )
        self.StreamBlocks = channel.unary_stream(
                '/injective_explorer_rpc.InjectiveExplorerRPC/StreamBlocks',
                request_serializer=exchange_dot_injective__explorer__rpc__pb2.StreamBlocksRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__explorer__rpc__pb2.StreamBlocksResponse.FromString,
                )


class InjectiveExplorerRPCServicer(object):
    """ExplorerAPI implements explorer data API for e.g. Blockchain Explorer
    """

    def GetAccountTxs(self, request, context):
        """GetAccountTxs returns tranctions involving in an account based upon params.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetContractTxs(self, request, context):
        """GetContractTxs returns contract-related transactions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlocks(self, request, context):
        """GetBlocks returns blocks based upon the request params
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlock(self, request, context):
        """GetBlock returns block based upon the height or hash
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetValidators(self, request, context):
        """GetValidators returns validators on the active chain
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetValidator(self, request, context):
        """GetValidator returns validator information on the active chain
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetValidatorUptime(self, request, context):
        """GetValidatorUptime returns validator uptime information on the active chain
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTxs(self, request, context):
        """GetTxs returns transactions based upon the request params
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTxByTxHash(self, request, context):
        """GetTxByTxHash returns certain transaction information by its tx hash.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPeggyDepositTxs(self, request, context):
        """GetPeggyDepositTxs returns the peggy deposit transactions based upon the
        request params
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPeggyWithdrawalTxs(self, request, context):
        """GetPeggyWithdrawalTxs returns the peggy withdrawal transactions based upon
        the request params
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIBCTransferTxs(self, request, context):
        """GetIBCTransferTxs returns the ibc transfer transactions based upon the
        request params
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWasmCodes(self, request, context):
        """GetWasmCodes lists all stored code
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWasmCodeByID(self, request, context):
        """GetWasmCodeById list cosmwasm code infor by ID
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWasmContracts(self, request, context):
        """GetWasmContracts lists all contracts
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWasmContractByAddress(self, request, context):
        """GetWasmContractByAddress list cosmwasm contract info by its address
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCw20Balance(self, request, context):
        """GetCw20Balance lists all cw20 balances of an injective account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Relayers(self, request, context):
        """Request relayers infos by marketIDs. If no ids are provided, all market with
        associated relayers are returned
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamTxs(self, request, context):
        """StreamTxs returns transactions based upon the request params
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamBlocks(self, request, context):
        """StreamBlocks returns the latest blocks
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InjectiveExplorerRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAccountTxs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountTxs,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetAccountTxsRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.GetAccountTxsResponse.SerializeToString,
            ),
            'GetContractTxs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetContractTxs,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetContractTxsRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.GetContractTxsResponse.SerializeToString,
            ),
            'GetBlocks': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlocks,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetBlocksRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.GetBlocksResponse.SerializeToString,
            ),
            'GetBlock': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlock,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetBlockRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.GetBlockResponse.SerializeToString,
            ),
            'GetValidators': grpc.unary_unary_rpc_method_handler(
                    servicer.GetValidators,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetValidatorsRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.GetValidatorsResponse.SerializeToString,
            ),
            'GetValidator': grpc.unary_unary_rpc_method_handler(
                    servicer.GetValidator,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetValidatorRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.GetValidatorResponse.SerializeToString,
            ),
            'GetValidatorUptime': grpc.unary_unary_rpc_method_handler(
                    servicer.GetValidatorUptime,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetValidatorUptimeRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.GetValidatorUptimeResponse.SerializeToString,
            ),
            'GetTxs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTxs,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetTxsRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.GetTxsResponse.SerializeToString,
            ),
            'GetTxByTxHash': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTxByTxHash,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetTxByTxHashRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.GetTxByTxHashResponse.SerializeToString,
            ),
            'GetPeggyDepositTxs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPeggyDepositTxs,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetPeggyDepositTxsRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.GetPeggyDepositTxsResponse.SerializeToString,
            ),
            'GetPeggyWithdrawalTxs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPeggyWithdrawalTxs,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetPeggyWithdrawalTxsRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.GetPeggyWithdrawalTxsResponse.SerializeToString,
            ),
            'GetIBCTransferTxs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIBCTransferTxs,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetIBCTransferTxsRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.GetIBCTransferTxsResponse.SerializeToString,
            ),
            'GetWasmCodes': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWasmCodes,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetWasmCodesRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.GetWasmCodesResponse.SerializeToString,
            ),
            'GetWasmCodeByID': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWasmCodeByID,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetWasmCodeByIDRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.GetWasmCodeByIDResponse.SerializeToString,
            ),
            'GetWasmContracts': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWasmContracts,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetWasmContractsRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.GetWasmContractsResponse.SerializeToString,
            ),
            'GetWasmContractByAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWasmContractByAddress,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetWasmContractByAddressRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.GetWasmContractByAddressResponse.SerializeToString,
            ),
            'GetCw20Balance': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCw20Balance,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.GetCw20BalanceRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.GetCw20BalanceResponse.SerializeToString,
            ),
            'Relayers': grpc.unary_unary_rpc_method_handler(
                    servicer.Relayers,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.RelayersRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.RelayersResponse.SerializeToString,
            ),
            'StreamTxs': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamTxs,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.StreamTxsRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.StreamTxsResponse.SerializeToString,
            ),
            'StreamBlocks': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamBlocks,
                    request_deserializer=exchange_dot_injective__explorer__rpc__pb2.StreamBlocksRequest.FromString,
                    response_serializer=exchange_dot_injective__explorer__rpc__pb2.StreamBlocksResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective_explorer_rpc.InjectiveExplorerRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InjectiveExplorerRPC(object):
    """ExplorerAPI implements explorer data API for e.g. Blockchain Explorer
    """

    @staticmethod
    def GetAccountTxs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/GetAccountTxs',
            exchange_dot_injective__explorer__rpc__pb2.GetAccountTxsRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.GetAccountTxsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetContractTxs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/GetContractTxs',
            exchange_dot_injective__explorer__rpc__pb2.GetContractTxsRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.GetContractTxsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBlocks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/GetBlocks',
            exchange_dot_injective__explorer__rpc__pb2.GetBlocksRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.GetBlocksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/GetBlock',
            exchange_dot_injective__explorer__rpc__pb2.GetBlockRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.GetBlockResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetValidators(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/GetValidators',
            exchange_dot_injective__explorer__rpc__pb2.GetValidatorsRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.GetValidatorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetValidator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/GetValidator',
            exchange_dot_injective__explorer__rpc__pb2.GetValidatorRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.GetValidatorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetValidatorUptime(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/GetValidatorUptime',
            exchange_dot_injective__explorer__rpc__pb2.GetValidatorUptimeRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.GetValidatorUptimeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTxs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/GetTxs',
            exchange_dot_injective__explorer__rpc__pb2.GetTxsRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.GetTxsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTxByTxHash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/GetTxByTxHash',
            exchange_dot_injective__explorer__rpc__pb2.GetTxByTxHashRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.GetTxByTxHashResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPeggyDepositTxs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/GetPeggyDepositTxs',
            exchange_dot_injective__explorer__rpc__pb2.GetPeggyDepositTxsRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.GetPeggyDepositTxsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPeggyWithdrawalTxs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/GetPeggyWithdrawalTxs',
            exchange_dot_injective__explorer__rpc__pb2.GetPeggyWithdrawalTxsRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.GetPeggyWithdrawalTxsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIBCTransferTxs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/GetIBCTransferTxs',
            exchange_dot_injective__explorer__rpc__pb2.GetIBCTransferTxsRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.GetIBCTransferTxsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWasmCodes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/GetWasmCodes',
            exchange_dot_injective__explorer__rpc__pb2.GetWasmCodesRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.GetWasmCodesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWasmCodeByID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/GetWasmCodeByID',
            exchange_dot_injective__explorer__rpc__pb2.GetWasmCodeByIDRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.GetWasmCodeByIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWasmContracts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/GetWasmContracts',
            exchange_dot_injective__explorer__rpc__pb2.GetWasmContractsRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.GetWasmContractsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWasmContractByAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/GetWasmContractByAddress',
            exchange_dot_injective__explorer__rpc__pb2.GetWasmContractByAddressRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.GetWasmContractByAddressResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCw20Balance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/GetCw20Balance',
            exchange_dot_injective__explorer__rpc__pb2.GetCw20BalanceRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.GetCw20BalanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Relayers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/Relayers',
            exchange_dot_injective__explorer__rpc__pb2.RelayersRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.RelayersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamTxs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/StreamTxs',
            exchange_dot_injective__explorer__rpc__pb2.StreamTxsRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.StreamTxsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamBlocks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_explorer_rpc.InjectiveExplorerRPC/StreamBlocks',
            exchange_dot_injective__explorer__rpc__pb2.StreamBlocksRequest.SerializeToString,
            exchange_dot_injective__explorer__rpc__pb2.StreamBlocksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/store/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ctendermint/store/types.proto\x12\x10tendermint.store\"/\n\x0f\x42lockStoreState\x12\x0c\n\x04\x62\x61se\x18\x01 \x01(\x03\x12\x0e\n\x06height\x18\x02 \x01(\x03\x42\x39Z7github.com/tendermint/tendermint/proto/tendermint/storeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.store.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/tendermint/tendermint/proto/tendermint/store'
  _BLOCKSTORESTATE._serialized_start=50
  _BLOCKSTORESTATE._serialized_end=97
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/ocr/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from injective.ocr.v1beta1 import ocr_pb2 as injective_dot_ocr_dot_v1beta1_dot_ocr__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from injective.ocr.v1beta1 import genesis_pb2 as injective_dot_ocr_dot_v1beta1_dot_genesis__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!injective/ocr/v1beta1/query.proto\x12\x15injective.ocr.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x1finjective/ocr/v1beta1/ocr.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a#injective/ocr/v1beta1/genesis.proto\"\x14\n\x12QueryParamsRequest\"J\n\x13QueryParamsResponse\x12\x33\n\x06params\x18\x01 \x01(\x0b\x32\x1d.injective.ocr.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\")\n\x16QueryFeedConfigRequest\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\"\x92\x01\n\x17QueryFeedConfigResponse\x12?\n\x10\x66\x65\x65\x64_config_info\x18\x01 \x01(\x0b\x32%.injective.ocr.v1beta1.FeedConfigInfo\x12\x36\n\x0b\x66\x65\x65\x64_config\x18\x02 \x01(\x0b\x32!.injective.ocr.v1beta1.FeedConfig\"-\n\x1aQueryFeedConfigInfoRequest\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\"\x9d\x01\n\x1bQueryFeedConfigInfoResponse\x12?\n\x10\x66\x65\x65\x64_config_info\x18\x01 \x01(\x0b\x32%.injective.ocr.v1beta1.FeedConfigInfo\x12=\n\x0f\x65poch_and_round\x18\x02 \x01(\x0b\x32$.injective.ocr.v1beta1.EpochAndRound\"*\n\x17QueryLatestRoundRequest\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\"f\n\x18QueryLatestRoundResponse\x12\x17\n\x0flatest_round_id\x18\x01 \x01(\x04\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.injective.ocr.v1beta1.Transmission\"8\n%QueryLatestTransmissionDetailsRequest\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\"\xb1\x01\n&QueryLatestTransmissionDetailsResponse\x12\x15\n\rconfig_digest\x18\x01 \x01(\x0c\x12=\n\x0f\x65poch_and_round\x18\x02 \x01(\x0b\x32$.injective.ocr.v1beta1.EpochAndRound\x12\x31\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32#.injective.ocr.v1beta1.Transmission\"-\n\x16QueryOwedAmountRequest\x12\x13\n\x0btransmitter\x18\x01 \x01(\t\"J\n\x17QueryOwedAmountResponse\x12/\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x19\n\x17QueryModuleStateRequest\"N\n\x18QueryModuleStateResponse\x12\x32\n\x05state\x18\x01 \x01(\x0b\x32#.injective.ocr.v1beta1.GenesisState2\xbb\t\n\x05Query\x12\x86\x01\n\x06Params\x12).injective.ocr.v1beta1.QueryParamsRequest\x1a*.injective.ocr.v1beta1.QueryParamsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/chainlink/ocr/v1beta1/params\x12\xa1\x01\n\nFeedConfig\x12-.injective.ocr.v1beta1.QueryFeedConfigRequest\x1a..injective.ocr.v1beta1.QueryFeedConfigResponse\"4\x82\xd3\xe4\x93\x02.\x12,/chainlink/ocr/v1beta1/feed_config/{feed_id}\x12\xb2\x01\n\x0e\x46\x65\x65\x64\x43onfigInfo\x12\x31.injective.ocr.v1beta1.QueryFeedConfigInfoRequest\x1a\x32.injective.ocr.v1beta1.QueryFeedConfigInfoResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/chainlink/ocr/v1beta1/feed_config_info/{feed_id}\x12\xa5\x01\n\x0bLatestRound\x12..injective.ocr.v1beta1.QueryLatestRoundRequest\x1a/.injective.ocr.v1beta1.QueryLatestRoundResponse\"5\x82\xd3\xe4\x93\x02/\x12-/chainlink/ocr/v1beta1/latest_round/{feed_id}\x12\xde\x01\n\x19LatestTransmissionDetails\x12<.injective.ocr.v1beta1.QueryLatestTransmissionDetailsRequest\x1a=.injective.ocr.v1beta1.QueryLatestTransmissionDetailsResponse\"D\x82\xd3\xe4\x93\x02>\x12</chainlink/ocr/v1beta1/latest_transmission_details/{feed_id}\x12\xa5\x01\n\nOwedAmount\x12-.injective.ocr.v1beta1.QueryOwedAmountRequest\x1a..injective.ocr.v1beta1.QueryOwedAmountResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/chainlink/ocr/v1beta1/owed_amount/{transmitter}\x12\x9e\x01\n\x0eOcrModuleState\x12..injective.ocr.v1beta1.QueryModuleStateRequest\x1a/.injective.ocr.v1beta1.QueryModuleStateResponse\"+\x82\xd3\xe4\x93\x02%\x12#/chainlink/ocr/v1beta1/module_stateBKZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.ocr.v1beta1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYOWEDAMOUNTRESPONSE.fields_by_name['amount']._options = None
  _QUERYOWEDAMOUNTRESPONSE.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\037\022\035/chainlink/ocr/v1beta1/params'
  _QUERY.methods_by_name['FeedConfig']._options = None
  _QUERY.methods_by_name['FeedConfig']._serialized_options = b'\202\323\344\223\002.\022,/chainlink/ocr/v1beta1/feed_config/{feed_id}'
  _QUERY.methods_by_name['FeedConfigInfo']._options = None
  _QUERY.methods_by_name['FeedConfigInfo']._serialized_options = b'\202\323\344\223\0023\0221/chainlink/ocr/v1beta1/feed_config_info/{feed_id}'
  _QUERY.methods_by_name['LatestRound']._options = None
  _QUERY.methods_by_name['LatestRound']._serialized_options = b'\202\323\344\223\002/\022-/chainlink/ocr/v1beta1/latest_round/{feed_id}'
  _QUERY.methods_by_name['LatestTransmissionDetails']._options = None
  _QUERY.methods_by_name['LatestTransmissionDetails']._serialized_options = b'\202\323\344\223\002>\022</chainlink/ocr/v1beta1/latest_transmission_details/{feed_id}'
  _QUERY.methods_by_name['OwedAmount']._options = None
  _QUERY.methods_by_name['OwedAmount']._serialized_options = b'\202\323\344\223\0022\0220/chainlink/ocr/v1beta1/owed_amount/{transmitter}'
  _QUERY.methods_by_name['OcrModuleState']._options = None
  _QUERY.methods_by_name['OcrModuleState']._serialized_options = b'\202\323\344\223\002%\022#/chainlink/ocr/v1beta1/module_state'
  _QUERYPARAMSREQUEST._serialized_start=214
  _QUERYPARAMSREQUEST._serialized_end=234
  _QUERYPARAMSRESPONSE._serialized_start=236
  _QUERYPARAMSRESPONSE._serialized_end=310
  _QUERYFEEDCONFIGREQUEST._serialized_start=312
  _QUERYFEEDCONFIGREQUEST._serialized_end=353
  _QUERYFEEDCONFIGRESPONSE._serialized_start=356
  _QUERYFEEDCONFIGRESPONSE._serialized_end=502
  _QUERYFEEDCONFIGINFOREQUEST._serialized_start=504
  _QUERYFEEDCONFIGINFOREQUEST._serialized_end=549
  _QUERYFEEDCONFIGINFORESPONSE._serialized_start=552
  _QUERYFEEDCONFIGINFORESPONSE._serialized_end=709
  _QUERYLATESTROUNDREQUEST._serialized_start=711
  _QUERYLATESTROUNDREQUEST._serialized_end=753
  _QUERYLATESTROUNDRESPONSE._serialized_start=755
  _QUERYLATESTROUNDRESPONSE._serialized_end=857
  _QUERYLATESTTRANSMISSIONDETAILSREQUEST._serialized_start=859
  _QUERYLATESTTRANSMISSIONDETAILSREQUEST._serialized_end=915
  _QUERYLATESTTRANSMISSIONDETAILSRESPONSE._serialized_start=918
  _QUERYLATESTTRANSMISSIONDETAILSRESPONSE._serialized_end=1095
  _QUERYOWEDAMOUNTREQUEST._serialized_start=1097
  _QUERYOWEDAMOUNTREQUEST._serialized_end=1142
  _QUERYOWEDAMOUNTRESPONSE._serialized_start=1144
  _QUERYOWEDAMOUNTRESPONSE._serialized_end=1218
  _QUERYMODULESTATEREQUEST._serialized_start=1220
  _QUERYMODULESTATEREQUEST._serialized_end=1245
  _QUERYMODULESTATERESPONSE._serialized_start=1247
  _QUERYMODULESTATERESPONSE._serialized_end=1325
  _QUERY._serialized_start=1328
  _QUERY._serialized_end=2539
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1einjective/peggy/v1/types.proto\x12\x12injective.peggy.v1\x1a\x14gogoproto/gogo.proto\":\n\x0f\x42ridgeValidator\x12\r\n\x05power\x18\x01 \x01(\x04\x12\x18\n\x10\x65thereum_address\x18\x02 \x01(\t\"\xba\x01\n\x06Valset\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x34\n\x07members\x18\x02 \x03(\x0b\x32#.injective.peggy.v1.BridgeValidator\x12\x0e\n\x06height\x18\x03 \x01(\x04\x12\x45\n\rreward_amount\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x14\n\x0creward_token\x18\x05 \x01(\t\"]\n\x1fLastObservedEthereumBlockHeight\x12\x1b\n\x13\x63osmos_block_height\x18\x01 \x01(\x04\x12\x1d\n\x15\x65thereum_block_height\x18\x02 \x01(\x04\"M\n\x0eLastClaimEvent\x12\x1c\n\x14\x65thereum_event_nonce\x18\x01 \x01(\x04\x12\x1d\n\x15\x65thereum_event_height\x18\x02 \x01(\x04\",\n\x0c\x45RC20ToDenom\x12\r\n\x05\x65rc20\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\tBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.peggy.v1.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types'
  _VALSET.fields_by_name['reward_amount']._options = None
  _VALSET.fields_by_name['reward_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _BRIDGEVALIDATOR._serialized_start=76
  _BRIDGEVALIDATOR._serialized_end=134
  _VALSET._serialized_start=137
  _VALSET._serialized_end=323
  _LASTOBSERVEDETHEREUMBLOCKHEIGHT._serialized_start=325
  _LASTOBSERVEDETHEREUMBLOCKHEIGHT._serialized_end=418
  _LASTCLAIMEVENT._serialized_start=420
  _LASTCLAIMEVENT._serialized_end=497
  _ERC20TODENOM._serialized_start=499
  _ERC20TODENOM._serialized_end=543
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ibc.core.channel.v1 import query_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_query__pb2


class QueryStub(object):
    """Query provides defines the gRPC querier service
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Channel = channel.unary_unary(
                '/ibc.core.channel.v1.Query/Channel',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelResponse.FromString,
                )
        self.Channels = channel.unary_unary(
                '/ibc.core.channel.v1.Query/Channels',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelsRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelsResponse.FromString,
                )
        self.ConnectionChannels = channel.unary_unary(
                '/ibc.core.channel.v1.Query/ConnectionChannels',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryConnectionChannelsRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryConnectionChannelsResponse.FromString,
                )
        self.ChannelClientState = channel.unary_unary(
                '/ibc.core.channel.v1.Query/ChannelClientState',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelClientStateRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelClientStateResponse.FromString,
                )
        self.ChannelConsensusState = channel.unary_unary(
                '/ibc.core.channel.v1.Query/ChannelConsensusState',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelConsensusStateRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelConsensusStateResponse.FromString,
                )
        self.PacketCommitment = channel.unary_unary(
                '/ibc.core.channel.v1.Query/PacketCommitment',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentResponse.FromString,
                )
        self.PacketCommitments = channel.unary_unary(
                '/ibc.core.channel.v1.Query/PacketCommitments',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentsRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentsResponse.FromString,
                )
        self.PacketReceipt = channel.unary_unary(
                '/ibc.core.channel.v1.Query/PacketReceipt',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketReceiptRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketReceiptResponse.FromString,
                )
        self.PacketAcknowledgement = channel.unary_unary(
                '/ibc.core.channel.v1.Query/PacketAcknowledgement',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementResponse.FromString,
                )
        self.PacketAcknowledgements = channel.unary_unary(
                '/ibc.core.channel.v1.Query/PacketAcknowledgements',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementsRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementsResponse.FromString,
                )
        self.UnreceivedPackets = channel.unary_unary(
                '/ibc.core.channel.v1.Query/UnreceivedPackets',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedPacketsRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedPacketsResponse.FromString,
                )
        self.UnreceivedAcks = channel.unary_unary(
                '/ibc.core.channel.v1.Query/UnreceivedAcks',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedAcksRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedAcksResponse.FromString,
                )
        self.NextSequenceReceive = channel.unary_unary(
                '/ibc.core.channel.v1.Query/NextSequenceReceive',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryNextSequenceReceiveRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryNextSequenceReceiveResponse.FromString,
                )


class QueryServicer(object):
    """Query provides defines the gRPC querier service
    """

    def Channel(self, request, context):
        """Channel queries an IBC Channel.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Channels(self, request, context):
        """Channels queries all the IBC channels of a chain.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConnectionChannels(self, request, context):
        """ConnectionChannels queries all the channels associated with a connection
        end.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelClientState(self, request, context):
        """ChannelClientState queries for the client state for the channel associated
        with the provided channel identifiers.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelConsensusState(self, request, context):
        """ChannelConsensusState queries for the consensus state for the channel
        associated with the provided channel identifiers.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PacketCommitment(self, request, context):
        """PacketCommitment queries a stored packet commitment hash.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PacketCommitments(self, request, context):
        """PacketCommitments returns all the packet commitments hashes associated
        with a channel.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PacketReceipt(self, request, context):
        """PacketReceipt queries if a given packet sequence has been received on the
        queried chain
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PacketAcknowledgement(self, request, context):
        """PacketAcknowledgement queries a stored packet acknowledgement hash.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PacketAcknowledgements(self, request, context):
        """PacketAcknowledgements returns all the packet acknowledgements associated
        with a channel.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnreceivedPackets(self, request, context):
        """UnreceivedPackets returns all the unreceived IBC packets associated with a
        channel and sequences.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnreceivedAcks(self, request, context):
        """UnreceivedAcks returns all the unreceived IBC acknowledgements associated
        with a channel and sequences.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NextSequenceReceive(self, request, context):
        """NextSequenceReceive returns the next receive sequence for a given channel.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Channel': grpc.unary_unary_rpc_method_handler(
                    servicer.Channel,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelRequest.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelResponse.SerializeToString,
            ),
            'Channels': grpc.unary_unary_rpc_method_handler(
                    servicer.Channels,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelsRequest.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelsResponse.SerializeToString,
            ),
            'ConnectionChannels': grpc.unary_unary_rpc_method_handler(
                    servicer.ConnectionChannels,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryConnectionChannelsRequest.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryConnectionChannelsResponse.SerializeToString,
            ),
            'ChannelClientState': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelClientState,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelClientStateRequest.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelClientStateResponse.SerializeToString,
            ),
            'ChannelConsensusState': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelConsensusState,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelConsensusStateRequest.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelConsensusStateResponse.SerializeToString,
            ),
            'PacketCommitment': grpc.unary_unary_rpc_method_handler(
                    servicer.PacketCommitment,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentRequest.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentResponse.SerializeToString,
            ),
            'PacketCommitments': grpc.unary_unary_rpc_method_handler(
                    servicer.PacketCommitments,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentsRequest.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentsResponse.SerializeToString,
            ),
            'PacketReceipt': grpc.unary_unary_rpc_method_handler(
                    servicer.PacketReceipt,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketReceiptRequest.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketReceiptResponse.SerializeToString,
            ),
            'PacketAcknowledgement': grpc.unary_unary_rpc_method_handler(
                    servicer.PacketAcknowledgement,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementRequest.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementResponse.SerializeToString,
            ),
            'PacketAcknowledgements': grpc.unary_unary_rpc_method_handler(
                    servicer.PacketAcknowledgements,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementsRequest.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementsResponse.SerializeToString,
            ),
            'UnreceivedPackets': grpc.unary_unary_rpc_method_handler(
                    servicer.UnreceivedPackets,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedPacketsRequest.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedPacketsResponse.SerializeToString,
            ),
            'UnreceivedAcks': grpc.unary_unary_rpc_method_handler(
                    servicer.UnreceivedAcks,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedAcksRequest.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedAcksResponse.SerializeToString,
            ),
            'NextSequenceReceive': grpc.unary_unary_rpc_method_handler(
                    servicer.NextSequenceReceive,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryNextSequenceReceiveRequest.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryNextSequenceReceiveResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ibc.core.channel.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query provides defines the gRPC querier service
    """

    @staticmethod
    def Channel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/Channel',
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelRequest.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Channels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/Channels',
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelsRequest.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConnectionChannels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/ConnectionChannels',
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryConnectionChannelsRequest.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryConnectionChannelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChannelClientState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/ChannelClientState',
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelClientStateRequest.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelClientStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChannelConsensusState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/ChannelConsensusState',
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelConsensusStateRequest.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelConsensusStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PacketCommitment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/PacketCommitment',
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentRequest.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PacketCommitments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/PacketCommitments',
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentsRequest.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PacketReceipt(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/PacketReceipt',
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketReceiptRequest.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketReceiptResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PacketAcknowledgement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/PacketAcknowledgement',
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementRequest.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PacketAcknowledgements(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/PacketAcknowledgements',
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementsRequest.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnreceivedPackets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/UnreceivedPackets',
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedPacketsRequest.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedPacketsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnreceivedAcks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/UnreceivedAcks',
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedAcksRequest.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedAcksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NextSequenceReceive(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/NextSequenceReceive',
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryNextSequenceReceiveRequest.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryNextSequenceReceiveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
